# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PipelineArgs', 'Pipeline']

@pulumi.input_type
class PipelineArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_details: Optional[pulumi.Input['PipelineGitDetailsArgs']] = None,
                 git_import_info: Optional[pulumi.Input['PipelineGitImportInfoArgs']] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_import_request: Optional[pulumi.Input['PipelinePipelineImportRequestArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 template_applied: Optional[pulumi.Input[_builtins.bool]] = None,
                 template_applied_pipeline_yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Pipeline resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input['PipelineGitDetailsArgs'] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input['PipelineGitImportInfoArgs'] git_import_info: Contains Git Information for importing entities from Git
        :param pulumi.Input[_builtins.bool] import_from_git: Flag to set if importing from Git
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input['PipelinePipelineImportRequestArgs'] pipeline_import_request: Contains parameters for importing a pipeline
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource. These should match the tag value passed in the YAML; if this parameter is null or not passed, the tags specified in YAML should also be null.
        :param pulumi.Input[_builtins.bool] template_applied: If true, returns Pipeline YAML with Templates applied on it.
        :param pulumi.Input[_builtins.str] template_applied_pipeline_yaml: Pipeline YAML after resolving Templates (returned as a String).
        :param pulumi.Input[_builtins.str] yaml: YAML of the pipeline. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "project_id", project_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if git_details is not None:
            pulumi.set(__self__, "git_details", git_details)
        if git_import_info is not None:
            pulumi.set(__self__, "git_import_info", git_import_info)
        if import_from_git is not None:
            pulumi.set(__self__, "import_from_git", import_from_git)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if pipeline_import_request is not None:
            pulumi.set(__self__, "pipeline_import_request", pipeline_import_request)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if template_applied is not None:
            pulumi.set(__self__, "template_applied", template_applied)
        if template_applied_pipeline_yaml is not None:
            pulumi.set(__self__, "template_applied_pipeline_yaml", template_applied_pipeline_yaml)
        if yaml is not None:
            pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Optional[pulumi.Input['PipelineGitDetailsArgs']]:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @git_details.setter
    def git_details(self, value: Optional[pulumi.Input['PipelineGitDetailsArgs']]):
        pulumi.set(self, "git_details", value)

    @_builtins.property
    @pulumi.getter(name="gitImportInfo")
    def git_import_info(self) -> Optional[pulumi.Input['PipelineGitImportInfoArgs']]:
        """
        Contains Git Information for importing entities from Git
        """
        return pulumi.get(self, "git_import_info")

    @git_import_info.setter
    def git_import_info(self, value: Optional[pulumi.Input['PipelineGitImportInfoArgs']]):
        pulumi.set(self, "git_import_info", value)

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to set if importing from Git
        """
        return pulumi.get(self, "import_from_git")

    @import_from_git.setter
    def import_from_git(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "import_from_git", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="pipelineImportRequest")
    def pipeline_import_request(self) -> Optional[pulumi.Input['PipelinePipelineImportRequestArgs']]:
        """
        Contains parameters for importing a pipeline
        """
        return pulumi.get(self, "pipeline_import_request")

    @pipeline_import_request.setter
    def pipeline_import_request(self, value: Optional[pulumi.Input['PipelinePipelineImportRequestArgs']]):
        pulumi.set(self, "pipeline_import_request", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource. These should match the tag value passed in the YAML; if this parameter is null or not passed, the tags specified in YAML should also be null.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="templateApplied")
    def template_applied(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, returns Pipeline YAML with Templates applied on it.
        """
        return pulumi.get(self, "template_applied")

    @template_applied.setter
    def template_applied(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "template_applied", value)

    @_builtins.property
    @pulumi.getter(name="templateAppliedPipelineYaml")
    def template_applied_pipeline_yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Pipeline YAML after resolving Templates (returned as a String).
        """
        return pulumi.get(self, "template_applied_pipeline_yaml")

    @template_applied_pipeline_yaml.setter
    def template_applied_pipeline_yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "template_applied_pipeline_yaml", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        YAML of the pipeline. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "yaml", value)


@pulumi.input_type
class _PipelineState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_details: Optional[pulumi.Input['PipelineGitDetailsArgs']] = None,
                 git_import_info: Optional[pulumi.Input['PipelineGitImportInfoArgs']] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_import_request: Optional[pulumi.Input['PipelinePipelineImportRequestArgs']] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 template_applied: Optional[pulumi.Input[_builtins.bool]] = None,
                 template_applied_pipeline_yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Pipeline resources.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input['PipelineGitDetailsArgs'] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input['PipelineGitImportInfoArgs'] git_import_info: Contains Git Information for importing entities from Git
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] import_from_git: Flag to set if importing from Git
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input['PipelinePipelineImportRequestArgs'] pipeline_import_request: Contains parameters for importing a pipeline
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource. These should match the tag value passed in the YAML; if this parameter is null or not passed, the tags specified in YAML should also be null.
        :param pulumi.Input[_builtins.bool] template_applied: If true, returns Pipeline YAML with Templates applied on it.
        :param pulumi.Input[_builtins.str] template_applied_pipeline_yaml: Pipeline YAML after resolving Templates (returned as a String).
        :param pulumi.Input[_builtins.str] yaml: YAML of the pipeline. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if git_details is not None:
            pulumi.set(__self__, "git_details", git_details)
        if git_import_info is not None:
            pulumi.set(__self__, "git_import_info", git_import_info)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if import_from_git is not None:
            pulumi.set(__self__, "import_from_git", import_from_git)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if pipeline_import_request is not None:
            pulumi.set(__self__, "pipeline_import_request", pipeline_import_request)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if template_applied is not None:
            pulumi.set(__self__, "template_applied", template_applied)
        if template_applied_pipeline_yaml is not None:
            pulumi.set(__self__, "template_applied_pipeline_yaml", template_applied_pipeline_yaml)
        if yaml is not None:
            pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Optional[pulumi.Input['PipelineGitDetailsArgs']]:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @git_details.setter
    def git_details(self, value: Optional[pulumi.Input['PipelineGitDetailsArgs']]):
        pulumi.set(self, "git_details", value)

    @_builtins.property
    @pulumi.getter(name="gitImportInfo")
    def git_import_info(self) -> Optional[pulumi.Input['PipelineGitImportInfoArgs']]:
        """
        Contains Git Information for importing entities from Git
        """
        return pulumi.get(self, "git_import_info")

    @git_import_info.setter
    def git_import_info(self, value: Optional[pulumi.Input['PipelineGitImportInfoArgs']]):
        pulumi.set(self, "git_import_info", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to set if importing from Git
        """
        return pulumi.get(self, "import_from_git")

    @import_from_git.setter
    def import_from_git(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "import_from_git", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="pipelineImportRequest")
    def pipeline_import_request(self) -> Optional[pulumi.Input['PipelinePipelineImportRequestArgs']]:
        """
        Contains parameters for importing a pipeline
        """
        return pulumi.get(self, "pipeline_import_request")

    @pipeline_import_request.setter
    def pipeline_import_request(self, value: Optional[pulumi.Input['PipelinePipelineImportRequestArgs']]):
        pulumi.set(self, "pipeline_import_request", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource. These should match the tag value passed in the YAML; if this parameter is null or not passed, the tags specified in YAML should also be null.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="templateApplied")
    def template_applied(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, returns Pipeline YAML with Templates applied on it.
        """
        return pulumi.get(self, "template_applied")

    @template_applied.setter
    def template_applied(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "template_applied", value)

    @_builtins.property
    @pulumi.getter(name="templateAppliedPipelineYaml")
    def template_applied_pipeline_yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Pipeline YAML after resolving Templates (returned as a String).
        """
        return pulumi.get(self, "template_applied_pipeline_yaml")

    @template_applied_pipeline_yaml.setter
    def template_applied_pipeline_yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "template_applied_pipeline_yaml", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        YAML of the pipeline. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "yaml", value)


@pulumi.type_token("harness:platform/pipeline:Pipeline")
class Pipeline(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_details: Optional[pulumi.Input[Union['PipelineGitDetailsArgs', 'PipelineGitDetailsArgsDict']]] = None,
                 git_import_info: Optional[pulumi.Input[Union['PipelineGitImportInfoArgs', 'PipelineGitImportInfoArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_import_request: Optional[pulumi.Input[Union['PipelinePipelineImportRequestArgs', 'PipelinePipelineImportRequestArgsDict']]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 template_applied: Optional[pulumi.Input[_builtins.bool]] = None,
                 template_applied_pipeline_yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Harness pipeline.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.Pipeline("example",
            identifier="identifier",
            org_id="orgIdentifier",
            project_id="projectIdentifier",
            name="name",
            git_details={
                "branch_name": "branchName",
                "commit_message": "commitMessage",
                "file_path": "filePath",
                "connector_ref": "connectorRef",
                "store_type": "REMOTE",
                "repo_name": "repoName",
            },
            tags={},
            yaml=\"\"\"pipeline:
            name: name
            identifier: identifier
            allowStageExecutions: false
            projectIdentifier: projectIdentifier
            orgIdentifier: orgIdentifier
            tags: {}
            stages:
                - stage:
                    name: dep
                    identifier: dep
                    description: \\"\\"
                    type: Deployment
                    spec:
                        serviceConfig:
                            serviceRef: service
                            serviceDefinition:
                                type: Kubernetes
                                spec:
                                    variables: []
                        infrastructure:
                            environmentRef: testenv
                            infrastructureDefinition:
                                type: KubernetesDirect
                                spec:
                                    connectorRef: testconf
                                    namespace: test
                                    releaseName: release-<+INFRA_KEY>
                            allowSimultaneousDeployments: false
                        execution:
                            steps:
                                - stepGroup:
                                        name: Canary Deployment
                                        identifier: canaryDepoyment
                                        steps:
                                            - step:
                                                name: Canary Deployment
                                                identifier: canaryDeployment
                                                type: K8sCanaryDeploy
                                                timeout: 10m
                                                spec:
                                                    instanceSelection:
                                                        type: Count
                                                        spec:
                                                            count: 1
                                                    skipDryRun: false
                                            - step:
                                                name: Canary Delete
                                                identifier: canaryDelete
                                                type: K8sCanaryDelete
                                                timeout: 10m
                                                spec: {}
                                        rollbackSteps:
                                            - step:
                                                name: Canary Delete
                                                identifier: rollbackCanaryDelete
                                                type: K8sCanaryDelete
                                                timeout: 10m
                                                spec: {}
                                - stepGroup:
                                        name: Primary Deployment
                                        identifier: primaryDepoyment
                                        steps:
                                            - step:
                                                name: Rolling Deployment
                                                identifier: rollingDeployment
                                                type: K8sRollingDeploy
                                                timeout: 10m
                                                spec:
                                                    skipDryRun: false
                                        rollbackSteps:
                                            - step:
                                                name: Rolling Rollback
                                                identifier: rollingRollback
                                                type: K8sRollingRollback
                                                timeout: 10m
                                                spec: {}
                            rollbackSteps: []
                    tags: {}
                    failureStrategies:
                        - onFailure:
                                errors:
                                    - AllErrors
                                action:
                                    type: StageRollback
        \"\"\")
        ### Importing Pipeline from Git
        test = harness.platform.Organization("test",
            identifier="identifier",
            name="name")
        test_pipeline = harness.platform.Pipeline("test",
            identifier="gitx",
            org_id="default",
            project_id="V",
            name="gitx",
            import_from_git=True,
            git_import_info={
                "branch_name": "main",
                "file_path": ".harness/gitx.yaml",
                "connector_ref": "account.DoNotDeleteGithub",
                "repo_name": "open-repo",
            },
            pipeline_import_request={
                "pipeline_name": "gitx",
                "pipeline_description": "Pipeline Description",
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import pipeline from default branch

        ```sh
        $ pulumi import harness:platform/pipeline:Pipeline example <org_id>/<project_id>/<pipeline_id>
        ```

        Import pipeline from non default branch

        ```sh
        $ pulumi import harness:platform/pipeline:Pipeline example <org_id>/<project_id>/<pipeline_id>/<branch>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Union['PipelineGitDetailsArgs', 'PipelineGitDetailsArgsDict']] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input[Union['PipelineGitImportInfoArgs', 'PipelineGitImportInfoArgsDict']] git_import_info: Contains Git Information for importing entities from Git
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] import_from_git: Flag to set if importing from Git
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[Union['PipelinePipelineImportRequestArgs', 'PipelinePipelineImportRequestArgsDict']] pipeline_import_request: Contains parameters for importing a pipeline
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource. These should match the tag value passed in the YAML; if this parameter is null or not passed, the tags specified in YAML should also be null.
        :param pulumi.Input[_builtins.bool] template_applied: If true, returns Pipeline YAML with Templates applied on it.
        :param pulumi.Input[_builtins.str] template_applied_pipeline_yaml: Pipeline YAML after resolving Templates (returned as a String).
        :param pulumi.Input[_builtins.str] yaml: YAML of the pipeline. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PipelineArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness pipeline.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.Pipeline("example",
            identifier="identifier",
            org_id="orgIdentifier",
            project_id="projectIdentifier",
            name="name",
            git_details={
                "branch_name": "branchName",
                "commit_message": "commitMessage",
                "file_path": "filePath",
                "connector_ref": "connectorRef",
                "store_type": "REMOTE",
                "repo_name": "repoName",
            },
            tags={},
            yaml=\"\"\"pipeline:
            name: name
            identifier: identifier
            allowStageExecutions: false
            projectIdentifier: projectIdentifier
            orgIdentifier: orgIdentifier
            tags: {}
            stages:
                - stage:
                    name: dep
                    identifier: dep
                    description: \\"\\"
                    type: Deployment
                    spec:
                        serviceConfig:
                            serviceRef: service
                            serviceDefinition:
                                type: Kubernetes
                                spec:
                                    variables: []
                        infrastructure:
                            environmentRef: testenv
                            infrastructureDefinition:
                                type: KubernetesDirect
                                spec:
                                    connectorRef: testconf
                                    namespace: test
                                    releaseName: release-<+INFRA_KEY>
                            allowSimultaneousDeployments: false
                        execution:
                            steps:
                                - stepGroup:
                                        name: Canary Deployment
                                        identifier: canaryDepoyment
                                        steps:
                                            - step:
                                                name: Canary Deployment
                                                identifier: canaryDeployment
                                                type: K8sCanaryDeploy
                                                timeout: 10m
                                                spec:
                                                    instanceSelection:
                                                        type: Count
                                                        spec:
                                                            count: 1
                                                    skipDryRun: false
                                            - step:
                                                name: Canary Delete
                                                identifier: canaryDelete
                                                type: K8sCanaryDelete
                                                timeout: 10m
                                                spec: {}
                                        rollbackSteps:
                                            - step:
                                                name: Canary Delete
                                                identifier: rollbackCanaryDelete
                                                type: K8sCanaryDelete
                                                timeout: 10m
                                                spec: {}
                                - stepGroup:
                                        name: Primary Deployment
                                        identifier: primaryDepoyment
                                        steps:
                                            - step:
                                                name: Rolling Deployment
                                                identifier: rollingDeployment
                                                type: K8sRollingDeploy
                                                timeout: 10m
                                                spec:
                                                    skipDryRun: false
                                        rollbackSteps:
                                            - step:
                                                name: Rolling Rollback
                                                identifier: rollingRollback
                                                type: K8sRollingRollback
                                                timeout: 10m
                                                spec: {}
                            rollbackSteps: []
                    tags: {}
                    failureStrategies:
                        - onFailure:
                                errors:
                                    - AllErrors
                                action:
                                    type: StageRollback
        \"\"\")
        ### Importing Pipeline from Git
        test = harness.platform.Organization("test",
            identifier="identifier",
            name="name")
        test_pipeline = harness.platform.Pipeline("test",
            identifier="gitx",
            org_id="default",
            project_id="V",
            name="gitx",
            import_from_git=True,
            git_import_info={
                "branch_name": "main",
                "file_path": ".harness/gitx.yaml",
                "connector_ref": "account.DoNotDeleteGithub",
                "repo_name": "open-repo",
            },
            pipeline_import_request={
                "pipeline_name": "gitx",
                "pipeline_description": "Pipeline Description",
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import pipeline from default branch

        ```sh
        $ pulumi import harness:platform/pipeline:Pipeline example <org_id>/<project_id>/<pipeline_id>
        ```

        Import pipeline from non default branch

        ```sh
        $ pulumi import harness:platform/pipeline:Pipeline example <org_id>/<project_id>/<pipeline_id>/<branch>
        ```

        :param str resource_name: The name of the resource.
        :param PipelineArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PipelineArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_details: Optional[pulumi.Input[Union['PipelineGitDetailsArgs', 'PipelineGitDetailsArgsDict']]] = None,
                 git_import_info: Optional[pulumi.Input[Union['PipelineGitImportInfoArgs', 'PipelineGitImportInfoArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_import_request: Optional[pulumi.Input[Union['PipelinePipelineImportRequestArgs', 'PipelinePipelineImportRequestArgsDict']]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 template_applied: Optional[pulumi.Input[_builtins.bool]] = None,
                 template_applied_pipeline_yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PipelineArgs.__new__(PipelineArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["git_details"] = git_details
            __props__.__dict__["git_import_info"] = git_import_info
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["import_from_git"] = import_from_git
            __props__.__dict__["name"] = name
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["pipeline_import_request"] = pipeline_import_request
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["template_applied"] = template_applied
            __props__.__dict__["template_applied_pipeline_yaml"] = template_applied_pipeline_yaml
            __props__.__dict__["yaml"] = yaml
        super(Pipeline, __self__).__init__(
            'harness:platform/pipeline:Pipeline',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            git_details: Optional[pulumi.Input[Union['PipelineGitDetailsArgs', 'PipelineGitDetailsArgsDict']]] = None,
            git_import_info: Optional[pulumi.Input[Union['PipelineGitImportInfoArgs', 'PipelineGitImportInfoArgsDict']]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            pipeline_import_request: Optional[pulumi.Input[Union['PipelinePipelineImportRequestArgs', 'PipelinePipelineImportRequestArgsDict']]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            template_applied: Optional[pulumi.Input[_builtins.bool]] = None,
            template_applied_pipeline_yaml: Optional[pulumi.Input[_builtins.str]] = None,
            yaml: Optional[pulumi.Input[_builtins.str]] = None) -> 'Pipeline':
        """
        Get an existing Pipeline resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Union['PipelineGitDetailsArgs', 'PipelineGitDetailsArgsDict']] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input[Union['PipelineGitImportInfoArgs', 'PipelineGitImportInfoArgsDict']] git_import_info: Contains Git Information for importing entities from Git
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] import_from_git: Flag to set if importing from Git
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[Union['PipelinePipelineImportRequestArgs', 'PipelinePipelineImportRequestArgsDict']] pipeline_import_request: Contains parameters for importing a pipeline
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource. These should match the tag value passed in the YAML; if this parameter is null or not passed, the tags specified in YAML should also be null.
        :param pulumi.Input[_builtins.bool] template_applied: If true, returns Pipeline YAML with Templates applied on it.
        :param pulumi.Input[_builtins.str] template_applied_pipeline_yaml: Pipeline YAML after resolving Templates (returned as a String).
        :param pulumi.Input[_builtins.str] yaml: YAML of the pipeline. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PipelineState.__new__(_PipelineState)

        __props__.__dict__["description"] = description
        __props__.__dict__["git_details"] = git_details
        __props__.__dict__["git_import_info"] = git_import_info
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["import_from_git"] = import_from_git
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["pipeline_import_request"] = pipeline_import_request
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["template_applied"] = template_applied
        __props__.__dict__["template_applied_pipeline_yaml"] = template_applied_pipeline_yaml
        __props__.__dict__["yaml"] = yaml
        return Pipeline(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> pulumi.Output['outputs.PipelineGitDetails']:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @_builtins.property
    @pulumi.getter(name="gitImportInfo")
    def git_import_info(self) -> pulumi.Output[Optional['outputs.PipelineGitImportInfo']]:
        """
        Contains Git Information for importing entities from Git
        """
        return pulumi.get(self, "git_import_info")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Flag to set if importing from Git
        """
        return pulumi.get(self, "import_from_git")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="pipelineImportRequest")
    def pipeline_import_request(self) -> pulumi.Output[Optional['outputs.PipelinePipelineImportRequest']]:
        """
        Contains parameters for importing a pipeline
        """
        return pulumi.get(self, "pipeline_import_request")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource. These should match the tag value passed in the YAML; if this parameter is null or not passed, the tags specified in YAML should also be null.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="templateApplied")
    def template_applied(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        If true, returns Pipeline YAML with Templates applied on it.
        """
        return pulumi.get(self, "template_applied")

    @_builtins.property
    @pulumi.getter(name="templateAppliedPipelineYaml")
    def template_applied_pipeline_yaml(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Pipeline YAML after resolving Templates (returned as a String).
        """
        return pulumi.get(self, "template_applied_pipeline_yaml")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> pulumi.Output[_builtins.str]:
        """
        YAML of the pipeline. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetTriggersResult',
    'AwaitableGetTriggersResult',
    'get_triggers',
    'get_triggers_output',
]

@pulumi.output_type
class GetTriggersResult:
    """
    A collection of values returned by getTriggers.
    """
    def __init__(__self__, description=None, id=None, identifier=None, ignore_error=None, name=None, org_id=None, project_id=None, tags=None, target_id=None, yaml=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if ignore_error and not isinstance(ignore_error, bool):
            raise TypeError("Expected argument 'ignore_error' to be a bool")
        pulumi.set(__self__, "ignore_error", ignore_error)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if target_id and not isinstance(target_id, str):
            raise TypeError("Expected argument 'target_id' to be a str")
        pulumi.set(__self__, "target_id", target_id)
        if yaml and not isinstance(yaml, str):
            raise TypeError("Expected argument 'yaml' to be a str")
        pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="ignoreError")
    def ignore_error(self) -> Optional[_builtins.bool]:
        """
        ignore error default false
        """
        return pulumi.get(self, "ignore_error")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="targetId")
    def target_id(self) -> _builtins.str:
        """
        Identifier of the target pipeline
        """
        return pulumi.get(self, "target_id")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> _builtins.str:
        """
        trigger yaml
        """
        return pulumi.get(self, "yaml")


class AwaitableGetTriggersResult(GetTriggersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTriggersResult(
            description=self.description,
            id=self.id,
            identifier=self.identifier,
            ignore_error=self.ignore_error,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            tags=self.tags,
            target_id=self.target_id,
            yaml=self.yaml)


def get_triggers(identifier: Optional[_builtins.str] = None,
                 ignore_error: Optional[_builtins.bool] = None,
                 name: Optional[_builtins.str] = None,
                 org_id: Optional[_builtins.str] = None,
                 project_id: Optional[_builtins.str] = None,
                 target_id: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTriggersResult:
    """
    Data source for retrieving a Harness trigger.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_triggers(identifier="identifier",
        org_id="org_id",
        project_id="project_id",
        target_id="pipeline_id")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.bool ignore_error: ignore error default false
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str target_id: Identifier of the target pipeline
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['ignoreError'] = ignore_error
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['targetId'] = target_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getTriggers:getTriggers', __args__, opts=opts, typ=GetTriggersResult).value

    return AwaitableGetTriggersResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        ignore_error=pulumi.get(__ret__, 'ignore_error'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'),
        target_id=pulumi.get(__ret__, 'target_id'),
        yaml=pulumi.get(__ret__, 'yaml'))
def get_triggers_output(identifier: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        ignore_error: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                        name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        org_id: Optional[pulumi.Input[_builtins.str]] = None,
                        project_id: Optional[pulumi.Input[_builtins.str]] = None,
                        target_id: Optional[pulumi.Input[_builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTriggersResult]:
    """
    Data source for retrieving a Harness trigger.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_triggers(identifier="identifier",
        org_id="org_id",
        project_id="project_id",
        target_id="pipeline_id")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.bool ignore_error: ignore error default false
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str target_id: Identifier of the target pipeline
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['ignoreError'] = ignore_error
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['targetId'] = target_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getTriggers:getTriggers', __args__, opts=opts, typ=GetTriggersResult)
    return __ret__.apply(lambda __response__: GetTriggersResult(
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        ignore_error=pulumi.get(__response__, 'ignore_error'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags'),
        target_id=pulumi.get(__response__, 'target_id'),
        yaml=pulumi.get(__response__, 'yaml')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MonitoredServiceArgs', 'MonitoredService']

@pulumi.input_type
class MonitoredServiceArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 request: Optional[pulumi.Input['MonitoredServiceRequestArgs']] = None):
        """
        The set of arguments for constructing a MonitoredService resource.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the monitored service.
        :param pulumi.Input[_builtins.str] org_id: Identifier of the organization in which the monitored service is configured.
        :param pulumi.Input[_builtins.str] project_id: Identifier of the project in which the monitored service is configured.
        :param pulumi.Input['MonitoredServiceRequestArgs'] request: Request for creating or updating a monitored service.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "project_id", project_id)
        if request is not None:
            pulumi.set(__self__, "request", request)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the monitored service.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the organization in which the monitored service is configured.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the project in which the monitored service is configured.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def request(self) -> Optional[pulumi.Input['MonitoredServiceRequestArgs']]:
        """
        Request for creating or updating a monitored service.
        """
        return pulumi.get(self, "request")

    @request.setter
    def request(self, value: Optional[pulumi.Input['MonitoredServiceRequestArgs']]):
        pulumi.set(self, "request", value)


@pulumi.input_type
class _MonitoredServiceState:
    def __init__(__self__, *,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 request: Optional[pulumi.Input['MonitoredServiceRequestArgs']] = None):
        """
        Input properties used for looking up and filtering MonitoredService resources.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the monitored service.
        :param pulumi.Input[_builtins.str] org_id: Identifier of the organization in which the monitored service is configured.
        :param pulumi.Input[_builtins.str] project_id: Identifier of the project in which the monitored service is configured.
        :param pulumi.Input['MonitoredServiceRequestArgs'] request: Request for creating or updating a monitored service.
        """
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if request is not None:
            pulumi.set(__self__, "request", request)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the monitored service.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the organization in which the monitored service is configured.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the project in which the monitored service is configured.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def request(self) -> Optional[pulumi.Input['MonitoredServiceRequestArgs']]:
        """
        Request for creating or updating a monitored service.
        """
        return pulumi.get(self, "request")

    @request.setter
    def request(self, value: Optional[pulumi.Input['MonitoredServiceRequestArgs']]):
        pulumi.set(self, "request", value)


@pulumi.type_token("harness:platform/monitoredService:MonitoredService")
class MonitoredService(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 request: Optional[pulumi.Input[Union['MonitoredServiceRequestArgs', 'MonitoredServiceRequestArgsDict']]] = None,
                 __props__=None):
        """
        Resource for creating a monitored service.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_harness as harness

        #Sample template for Elastic Search Log Health Source
        example = harness.platform.MonitoredService("example",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "name",
                    "identifier": "identifier",
                    "type": "ElasticSearch",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [
                            {
                                "name": "name",
                                "identifier": "infraquery",
                                "query": "query",
                                "index": "index",
                                "groupName": "Logs_Group",
                                "queryParams": {
                                    "index": "index",
                                    "serviceInstanceField": "serviceInstanceIdentifier",
                                    "timeStampIdentifier": "timeStampIdentifier",
                                    "timeStampFormat": "timeStampFormat",
                                    "messageIdentifier": "messageIdentifier",
                                },
                            },
                            {
                                "name": "name2",
                                "identifier": "errorquery",
                                "query": "query2",
                                "index": "index2",
                                "groupName": "Logs_Group",
                                "queryParams": {
                                    "index": "index",
                                    "serviceInstanceField": "serviceInstanceIdentifier",
                                    "timeStampIdentifier": "timeStampIdentifier",
                                    "timeStampFormat": "timeStampFormat",
                                    "messageIdentifier": "messageIdentifier",
                                },
                            },
                        ],
                    }),
                }],
                "change_sources": [
                    {
                        "name": "BAC",
                        "identifier": "BAC",
                        "type": "PagerDuty",
                        "enabled": True,
                        "spec": json.dumps({
                            "connectorRef": "account.pd",
                            "pagerDutyServiceId": "P0N21OB",
                        }),
                        "category": "Alert",
                    },
                    {
                        "name": "FH",
                        "identifier": "FH",
                        "type": "CustomIncident",
                        "enabled": True,
                        "spec": json.dumps({
                            "name": "FH",
                            "webhookUrl": "https://harness.io/cv/api/account/sampleAcc/org/sampleOrg/project/sampleProj/webhook/custom-change?monitoredServiceIdentifier=checkout_prod&changeSourceIdentifier=FH",
                            "webhookCurlCommand": "curl -X POST -H 'content-type: application/json' -H 'X-Api-Key: sample_api_key' --url 'https://harness.io/cv/api/account/sampleAcc/org/sampleOrg/project/sampleProj/webhook/custom-change?monitoredServiceIdentifier=checkout_prod&changeSourceIdentifier=FH' -d '{ \\"eventIdentifier\\": \\"<string>\\" (optional), \\"user\\": \\"user@harness.io\\", \\"startTime\\": timeInMs, \\"endTime\\": timeInMs, \\"eventDetail\\": { \\"description\\": \\"<String>\\", \\"changeEventDetailsLink\\": \\"urlString\\" (optional), \\"externalLinkToEntity\\": \\"urlString\\" (optional), \\"name\\": \\"changeEventName\\" } }'",
                            "type": "Alert",
                        }),
                        "category": "Alert",
                    },
                    {
                        "name": "customff",
                        "identifier": "customff",
                        "type": "CustomFF",
                        "enabled": True,
                        "category": "FeatureFlag",
                        "spec": json.dumps({
                            "type": "FeatureFlag",
                        }),
                    },
                    {
                        "name": "customdeploy",
                        "identifier": "customdeploy",
                        "type": "CustomDeploy",
                        "enabled": True,
                        "category": "Deployment",
                        "spec": json.dumps({
                            "type": "Deployment",
                        }),
                    },
                    {
                        "name": "customincident",
                        "identifier": "customincident",
                        "type": "CustomIncident",
                        "enabled": True,
                        "category": "Alert",
                        "spec": json.dumps({
                            "type": "Alert",
                            "authorizationToken": "abc",
                        }),
                    },
                ],
                "notification_rule_refs": [
                    {
                        "notification_rule_ref": "notification_rule_ref",
                        "enabled": True,
                    },
                    {
                        "notification_rule_ref": "notification_rule_ref1",
                        "enabled": False,
                    },
                ],
            })
        #Sample template for Sumologic Metrics Health Source
        example1 = harness.platform.MonitoredService("example1",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "sumologicmetrics",
                    "identifier": "sumo_metric_identifier",
                    "type": "SumologicMetrics",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [
                            {
                                "name": "metric_cpu",
                                "identifier": "metric_cpu",
                                "query": "metric=cpu",
                                "groupName": "g1",
                                "queryParams": {
                                    "serviceInstanceField": "_sourcehost",
                                },
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "liveMonitoringEnabled": "true",
                                "continuousVerificationEnabled": "true",
                                "sliEnabled": "false",
                                "metricThresholds": [
                                    {
                                        "type": "IgnoreThreshold",
                                        "spec": {
                                            "action": "Ignore",
                                        },
                                        "criteria": {
                                            "type": "Absolute",
                                            "spec": {
                                                "greaterThan": 100,
                                            },
                                        },
                                        "metricType": "Custom",
                                        "metricName": "metric_cpu",
                                    },
                                    {
                                        "type": "FailImmediately",
                                        "spec": {
                                            "action": "FailAfterOccurrence",
                                            "spec": {
                                                "count": 2,
                                            },
                                        },
                                        "criteria": {
                                            "type": "Absolute",
                                            "spec": {
                                                "greaterThan": 100,
                                            },
                                        },
                                        "metricType": "Custom",
                                        "metricName": "metric_cpu",
                                    },
                                ],
                            },
                            {
                                "name": "name2",
                                "identifier": "identifier2",
                                "groupName": "g2",
                                "query": "metric=memory",
                                "queryParams": {
                                    "serviceInstanceField": "_sourcehost",
                                },
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "liveMonitoringEnabled": "false",
                                "continuousVerificationEnabled": "false",
                                "sliEnabled": "false",
                            },
                        ],
                    }),
                }],
            })
        #Sample template for Sumologic Log Health Source
        example2 = harness.platform.MonitoredService("example2",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "sumologic",
                    "identifier": "sumo_metric_identifier",
                    "type": "SumologicLogs",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [
                            {
                                "name": "log1",
                                "identifier": "log1",
                                "query": "*",
                                "groupName": "Logs Group",
                                "queryParams": {
                                    "serviceInstanceField": "_sourcehost",
                                },
                            },
                            {
                                "name": "log2",
                                "identifier": "identifier2",
                                "groupName": "g2",
                                "query": "error",
                                "queryParams": {
                                    "serviceInstanceField": "_sourcehost",
                                },
                            },
                        ],
                    }),
                }],
            })
        #Sample template for Splunk Signal FX Health Source
        example3 = harness.platform.MonitoredService("example3",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "signalfxmetrics",
                    "identifier": "signalfxmetrics",
                    "type": "SplunkSignalFXMetrics",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [
                            {
                                "name": "metric_infra_cpu",
                                "identifier": "metric_infra_cpu",
                                "query": "***",
                                "groupName": "g",
                                "riskProfile": {
                                    "riskCategory": "Errors",
                                    "thresholdTypes": [
                                        "ACT_WHEN_HIGHER",
                                        "ACT_WHEN_LOWER",
                                    ],
                                },
                                "liveMonitoringEnabled": "true",
                                "continuousVerificationEnabled": "true",
                                "sliEnabled": "false",
                            },
                            {
                                "name": "name2",
                                "identifier": "identifier2",
                                "groupName": "g2",
                                "query": "*",
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "liveMonitoringEnabled": "true",
                                "continuousVerificationEnabled": "false",
                                "sliEnabled": "false",
                                "metricThresholds": [
                                    {
                                        "type": "IgnoreThreshold",
                                        "spec": {
                                            "action": "Ignore",
                                        },
                                        "criteria": {
                                            "type": "Absolute",
                                            "spec": {
                                                "greaterThan": 100,
                                            },
                                        },
                                        "metrictype": "Custom",
                                        "metricName": "identifier2",
                                    },
                                    {
                                        "type": "FailImmediately",
                                        "spec": {
                                            "action": "FailAfterOccurrence",
                                            "spec": {
                                                "count": 2,
                                            },
                                        },
                                        "criteria": {
                                            "type": "Absolute",
                                            "spec": {
                                                "greaterThan": 100,
                                            },
                                        },
                                        "metricType": "Custom",
                                        "metricName": "identifier2",
                                    },
                                ],
                            },
                        ],
                    }),
                }],
            })
        #Sample template for Grafana Loki Log Health Source
        example4 = harness.platform.MonitoredService("example4",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "Test",
                    "identifier": "Test",
                    "type": "GrafanaLokiLogs",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [
                            {
                                "name": "Demo",
                                "identifier": "Demo",
                                "query": "{job=~\\".+\\"}",
                                "groupName": "Log_Group",
                                "queryParams": {
                                    "serviceInstanceField": "job",
                                },
                            },
                            {
                                "name": "log2",
                                "identifier": "identifier2",
                                "groupName": "g2",
                                "query": "error",
                                "queryParams": {
                                    "serviceInstanceField": "_sourcehost",
                                },
                                "liveMonitoringEnabled": "false",
                                "continuousVerificationEnabled": "false",
                                "sliEnabled": "false",
                            },
                        ],
                    }),
                }],
            })
        #Sample template for Azure Metrics Health Source
        example5 = harness.platform.MonitoredService("example5",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "azure metrics verify step",
                    "identifier": "azure_metrics_verify_step",
                    "type": "AzureMetrics",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [
                            {
                                "name": "metric",
                                "identifier": "metric",
                                "query": "default",
                                "groupName": "g1",
                                "queryParams": {
                                    "serviceInstanceField": "host",
                                    "index": "/subscriptions/12d2db62-5aa9-471d-84bb-faa489b3e319/resourceGroups/srm-test/providers/Microsoft.ContainerService/managedClusters/srm-test",
                                    "healthSourceMetricName": "cpuUsagePercentage",
                                    "healthSourceMetricNamespace": "insights.container/nodes",
                                    "aggregationType": "average",
                                },
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "liveMonitoringEnabled": "true",
                                "continuousVerificationEnabled": "true",
                                "sliEnabled": "false",
                                "metricThresholds": [
                                    {
                                        "type": "IgnoreThreshold",
                                        "spec": {
                                            "action": "Ignore",
                                        },
                                        "criteria": {
                                            "type": "Absolute",
                                            "spec": {
                                                "greaterThan": 100,
                                            },
                                        },
                                        "metrictype": "Custom",
                                        "metricName": "metric",
                                    },
                                    {
                                        "type": "FailImmediately",
                                        "spec": {
                                            "action": "FailAfterOccurrence",
                                            "spec": {
                                                "count": 2,
                                            },
                                        },
                                        "criteria": {
                                            "type": "Absolute",
                                            "spec": {
                                                "greaterThan": 100,
                                            },
                                        },
                                        "metricType": "Custom",
                                        "metricName": "metric",
                                    },
                                ],
                            },
                            {
                                "name": "name2",
                                "identifier": "identifier2",
                                "groupName": "g2",
                                "queryParams": {
                                    "serviceInstanceField": "host",
                                    "index": "/subscriptions/12d2db62-5aa9-471d-84bb-faa489b3e319/resourceGroups/srm-test/providers/Microsoft.ContainerService/managedClusters/srm-test",
                                    "healthSourceMetricName": "cpuUsagePercentage",
                                    "healthSourceMetricNamespace": "insights.container/nodes",
                                    "aggregationType": "average",
                                },
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "liveMonitoringEnabled": "false",
                                "continuousVerificationEnabled": "false",
                                "sliEnabled": "false",
                            },
                        ],
                    }),
                }],
            })
        #Sample template for Azure Log Health Source
        example6 = harness.platform.MonitoredService("example6",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "Demo azure",
                    "identifier": "Demo_azure",
                    "type": "AzureLogs",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [{
                            "name": "name2",
                            "identifier": "identifier2",
                            "groupName": "g2",
                            "query": "*",
                            "queryParams": {
                                "serviceInstanceField": "Name",
                                "timeStampIdentifier": "StartedTime",
                                "messageIdentifier": "Image",
                                "index": "/subscriptions/12d2db62-5aa9-471d-84bb-faa489b3e319/resourceGroups/srm-test/providers/Microsoft.ContainerService/managedClusters/srm-test",
                            },
                            "liveMonitoringEnabled": "false",
                            "continuousVerificationEnabled": "false",
                        }],
                    }),
                }],
            })
        #Sample template for Prometheus Metrics Health Source
        example7 = harness.platform.MonitoredService("example7",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "prometheus metrics verify step",
                    "identifier": "prometheus_metrics",
                    "type": "Prometheus",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "metricDefinitions": [{
                            "identifier": "Prometheus_Metric",
                            "metricName": "Prometheus Metric",
                            "riskProfile": {
                                "riskCategory": "Performance_Other",
                                "thresholdTypes": ["ACT_WHEN_HIGHER"],
                            },
                            "analysis": {
                                "liveMonitoring": {
                                    "enabled": True,
                                },
                                "deploymentVerification": {
                                    "enabled": True,
                                    "serviceInstanceFieldName": "pod_name",
                                },
                            },
                            "query": "count(up{group=\\"cv\\",group=\\"cv\\"})",
                            "groupName": "met",
                            "isManualQuery": True,
                        }],
                        "metricPacks": [{
                            "identifier": "Custom",
                            "metricThresholds": [
                                {
                                    "type": "IgnoreThreshold",
                                    "spec": {
                                        "action": "Ignore",
                                    },
                                    "criteria": {
                                        "type": "Absolute",
                                        "spec": {
                                            "greaterThan": 100,
                                        },
                                    },
                                    "metrictype": "Custom",
                                    "metricName": "Prometheus Metric",
                                },
                                {
                                    "type": "FailImmediately",
                                    "spec": {
                                        "action": "FailAfterOccurrence",
                                        "spec": {
                                            "count": 2,
                                        },
                                    },
                                    "criteria": {
                                        "type": "Absolute",
                                        "spec": {
                                            "greaterThan": 100,
                                        },
                                    },
                                    "metricType": "Custom",
                                    "metricName": "Prometheus Metric",
                                },
                            ],
                        }],
                    }),
                }],
            })
        #Sample template for Datadog Metrics Health Source
        example8 = harness.platform.MonitoredService("example8",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "ddm",
                    "identifier": "ddm",
                    "type": "DatadogMetrics",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "feature": "Datadog Cloud Metrics",
                        "metricDefinitions": [
                            {
                                "metricName": "metric",
                                "metricPath": "M1",
                                "identifier": "metric",
                                "query": \"\"\"avg:kubernetes.cpu.limits{*}.rollup(avg, 60);
        avg:kubernetes.cpu.limits{*}.rollup(avg, 30);
        (a+b)/10\"\"\",
                                "isManualQuery": True,
                                "isCustomCreatedMetric": True,
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "analysis": {
                                    "liveMonitoring": {
                                        "enabled": True,
                                    },
                                    "deploymentVerification": {
                                        "enabled": True,
                                        "serviceInstanceFieldName": "pod",
                                    },
                                },
                            },
                            {
                                "metricName": "dashboard_metric_cpu",
                                "identifier": "metric_cpu",
                                "query": \"\"\"avg:kubernetes.cpu.limits{*}.rollup(avg, 60);
        avg:kubernetes.cpu.limits{*}.rollup(avg, 30);
        (a+b)/10\"\"\",
                                "isManualQuery": False,
                                "dashboardName": "dashboard",
                                "metricPath": "M1",
                                "groupingQuery": "avg:kubernetes.cpu.limits{*} by {host}.rollup(avg, 60)",
                                "metric": "kubernetes.cpu.limits",
                                "aggregation": "avg",
                                "isCustomCreatedMetric": True,
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "analysis": {
                                    "liveMonitoring": {
                                        "enabled": True,
                                    },
                                    "deploymentVerification": {
                                        "enabled": True,
                                        "serviceInstanceFieldName": "pod",
                                    },
                                },
                            },
                        ],
                        "metricPacks": [{
                            "identifier": "Custom",
                            "metricThresholds": [
                                {
                                    "type": "IgnoreThreshold",
                                    "spec": {
                                        "action": "Ignore",
                                    },
                                    "criteria": {
                                        "type": "Absolute",
                                        "spec": {
                                            "greaterThan": 100,
                                        },
                                    },
                                    "metrictype": "Custom",
                                    "metricName": "metric",
                                },
                                {
                                    "type": "FailImmediately",
                                    "spec": {
                                        "action": "FailAfterOccurrence",
                                        "spec": {
                                            "count": 2,
                                        },
                                    },
                                    "criteria": {
                                        "type": "Absolute",
                                        "spec": {
                                            "greaterThan": 100,
                                        },
                                    },
                                    "metricType": "Custom",
                                    "metricName": "metric",
                                },
                            ],
                        }],
                    }),
                }],
            })
        #Sample template for New Relic Metrics Health Source
        example9 = harness.platform.MonitoredService("example9",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "name",
                    "identifier": "identifier",
                    "type": "NewRelic",
                    "spec": json.dumps({
                        "connectorRef": "account.Newrelicautomation_do_not_delete",
                        "feature": "apm",
                        "applicationId": "107019083",
                        "applicationName": "My Application",
                        "metricData": {
                            "Performance": True,
                        },
                        "metricPacks": [{
                            "identifier": "Performance",
                        }],
                        "newRelicMetricDefinitions": [{
                            "identifier": "New_Relic_Metric",
                            "metricName": "New Relic Metric",
                            "riskProfile": {
                                "riskCategory": "Performance_Other",
                                "thresholdTypes": ["ACT_WHEN_HIGHER"],
                            },
                            "analysis": {
                                "deploymentVerification": {
                                    "enabled": True,
                                },
                            },
                            "groupName": "group1",
                            "nrql": "SELECT count(apm.service.instance.count) FROM Metric WHERE appName LIKE 'My Application' TIMESERIES",
                            "responseMapping": {
                                "metricValueJsonPath": "$.['timeSeries'].[*].['results'].[*].['count']",
                                "timestampJsonPath": "$.['timeSeries'].[*].['beginTimeSeconds']",
                            },
                        }],
                        "metricPacks": [{
                            "identifier": "Custom",
                            "metricThresholds": [
                                {
                                    "type": "IgnoreThreshold",
                                    "spec": {
                                        "action": "Ignore",
                                    },
                                    "criteria": {
                                        "type": "Absolute",
                                        "spec": {
                                            "greaterThan": 100,
                                        },
                                    },
                                    "metricType": "Custom",
                                    "metricName": "New Relic Metric",
                                },
                                {
                                    "type": "FailImmediately",
                                    "spec": {
                                        "action": "FailAfterOccurrence",
                                        "spec": {
                                            "count": 2,
                                        },
                                    },
                                    "criteria": {
                                        "type": "Absolute",
                                        "spec": {
                                            "greaterThan": 100,
                                        },
                                    },
                                    "metricType": "Custom",
                                    "metricName": "New Relic Metric",
                                },
                            ],
                        }],
                    }),
                }],
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level monitored_service

        ```sh
        $ pulumi import harness:platform/monitoredService:MonitoredService example <monitored_service_id>
        ```

        Import organization level monitored_service

        ```sh
        $ pulumi import harness:platform/monitoredService:MonitoredService example <org_id>/<monitored_service_id>
        ```

        Import project level monitored_service

        ```sh
        $ pulumi import harness:platform/monitoredService:MonitoredService example <org_id>/<project_id>/<monitored_service_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the monitored service.
        :param pulumi.Input[_builtins.str] org_id: Identifier of the organization in which the monitored service is configured.
        :param pulumi.Input[_builtins.str] project_id: Identifier of the project in which the monitored service is configured.
        :param pulumi.Input[Union['MonitoredServiceRequestArgs', 'MonitoredServiceRequestArgsDict']] request: Request for creating or updating a monitored service.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MonitoredServiceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a monitored service.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_harness as harness

        #Sample template for Elastic Search Log Health Source
        example = harness.platform.MonitoredService("example",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "name",
                    "identifier": "identifier",
                    "type": "ElasticSearch",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [
                            {
                                "name": "name",
                                "identifier": "infraquery",
                                "query": "query",
                                "index": "index",
                                "groupName": "Logs_Group",
                                "queryParams": {
                                    "index": "index",
                                    "serviceInstanceField": "serviceInstanceIdentifier",
                                    "timeStampIdentifier": "timeStampIdentifier",
                                    "timeStampFormat": "timeStampFormat",
                                    "messageIdentifier": "messageIdentifier",
                                },
                            },
                            {
                                "name": "name2",
                                "identifier": "errorquery",
                                "query": "query2",
                                "index": "index2",
                                "groupName": "Logs_Group",
                                "queryParams": {
                                    "index": "index",
                                    "serviceInstanceField": "serviceInstanceIdentifier",
                                    "timeStampIdentifier": "timeStampIdentifier",
                                    "timeStampFormat": "timeStampFormat",
                                    "messageIdentifier": "messageIdentifier",
                                },
                            },
                        ],
                    }),
                }],
                "change_sources": [
                    {
                        "name": "BAC",
                        "identifier": "BAC",
                        "type": "PagerDuty",
                        "enabled": True,
                        "spec": json.dumps({
                            "connectorRef": "account.pd",
                            "pagerDutyServiceId": "P0N21OB",
                        }),
                        "category": "Alert",
                    },
                    {
                        "name": "FH",
                        "identifier": "FH",
                        "type": "CustomIncident",
                        "enabled": True,
                        "spec": json.dumps({
                            "name": "FH",
                            "webhookUrl": "https://harness.io/cv/api/account/sampleAcc/org/sampleOrg/project/sampleProj/webhook/custom-change?monitoredServiceIdentifier=checkout_prod&changeSourceIdentifier=FH",
                            "webhookCurlCommand": "curl -X POST -H 'content-type: application/json' -H 'X-Api-Key: sample_api_key' --url 'https://harness.io/cv/api/account/sampleAcc/org/sampleOrg/project/sampleProj/webhook/custom-change?monitoredServiceIdentifier=checkout_prod&changeSourceIdentifier=FH' -d '{ \\"eventIdentifier\\": \\"<string>\\" (optional), \\"user\\": \\"user@harness.io\\", \\"startTime\\": timeInMs, \\"endTime\\": timeInMs, \\"eventDetail\\": { \\"description\\": \\"<String>\\", \\"changeEventDetailsLink\\": \\"urlString\\" (optional), \\"externalLinkToEntity\\": \\"urlString\\" (optional), \\"name\\": \\"changeEventName\\" } }'",
                            "type": "Alert",
                        }),
                        "category": "Alert",
                    },
                    {
                        "name": "customff",
                        "identifier": "customff",
                        "type": "CustomFF",
                        "enabled": True,
                        "category": "FeatureFlag",
                        "spec": json.dumps({
                            "type": "FeatureFlag",
                        }),
                    },
                    {
                        "name": "customdeploy",
                        "identifier": "customdeploy",
                        "type": "CustomDeploy",
                        "enabled": True,
                        "category": "Deployment",
                        "spec": json.dumps({
                            "type": "Deployment",
                        }),
                    },
                    {
                        "name": "customincident",
                        "identifier": "customincident",
                        "type": "CustomIncident",
                        "enabled": True,
                        "category": "Alert",
                        "spec": json.dumps({
                            "type": "Alert",
                            "authorizationToken": "abc",
                        }),
                    },
                ],
                "notification_rule_refs": [
                    {
                        "notification_rule_ref": "notification_rule_ref",
                        "enabled": True,
                    },
                    {
                        "notification_rule_ref": "notification_rule_ref1",
                        "enabled": False,
                    },
                ],
            })
        #Sample template for Sumologic Metrics Health Source
        example1 = harness.platform.MonitoredService("example1",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "sumologicmetrics",
                    "identifier": "sumo_metric_identifier",
                    "type": "SumologicMetrics",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [
                            {
                                "name": "metric_cpu",
                                "identifier": "metric_cpu",
                                "query": "metric=cpu",
                                "groupName": "g1",
                                "queryParams": {
                                    "serviceInstanceField": "_sourcehost",
                                },
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "liveMonitoringEnabled": "true",
                                "continuousVerificationEnabled": "true",
                                "sliEnabled": "false",
                                "metricThresholds": [
                                    {
                                        "type": "IgnoreThreshold",
                                        "spec": {
                                            "action": "Ignore",
                                        },
                                        "criteria": {
                                            "type": "Absolute",
                                            "spec": {
                                                "greaterThan": 100,
                                            },
                                        },
                                        "metricType": "Custom",
                                        "metricName": "metric_cpu",
                                    },
                                    {
                                        "type": "FailImmediately",
                                        "spec": {
                                            "action": "FailAfterOccurrence",
                                            "spec": {
                                                "count": 2,
                                            },
                                        },
                                        "criteria": {
                                            "type": "Absolute",
                                            "spec": {
                                                "greaterThan": 100,
                                            },
                                        },
                                        "metricType": "Custom",
                                        "metricName": "metric_cpu",
                                    },
                                ],
                            },
                            {
                                "name": "name2",
                                "identifier": "identifier2",
                                "groupName": "g2",
                                "query": "metric=memory",
                                "queryParams": {
                                    "serviceInstanceField": "_sourcehost",
                                },
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "liveMonitoringEnabled": "false",
                                "continuousVerificationEnabled": "false",
                                "sliEnabled": "false",
                            },
                        ],
                    }),
                }],
            })
        #Sample template for Sumologic Log Health Source
        example2 = harness.platform.MonitoredService("example2",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "sumologic",
                    "identifier": "sumo_metric_identifier",
                    "type": "SumologicLogs",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [
                            {
                                "name": "log1",
                                "identifier": "log1",
                                "query": "*",
                                "groupName": "Logs Group",
                                "queryParams": {
                                    "serviceInstanceField": "_sourcehost",
                                },
                            },
                            {
                                "name": "log2",
                                "identifier": "identifier2",
                                "groupName": "g2",
                                "query": "error",
                                "queryParams": {
                                    "serviceInstanceField": "_sourcehost",
                                },
                            },
                        ],
                    }),
                }],
            })
        #Sample template for Splunk Signal FX Health Source
        example3 = harness.platform.MonitoredService("example3",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "signalfxmetrics",
                    "identifier": "signalfxmetrics",
                    "type": "SplunkSignalFXMetrics",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [
                            {
                                "name": "metric_infra_cpu",
                                "identifier": "metric_infra_cpu",
                                "query": "***",
                                "groupName": "g",
                                "riskProfile": {
                                    "riskCategory": "Errors",
                                    "thresholdTypes": [
                                        "ACT_WHEN_HIGHER",
                                        "ACT_WHEN_LOWER",
                                    ],
                                },
                                "liveMonitoringEnabled": "true",
                                "continuousVerificationEnabled": "true",
                                "sliEnabled": "false",
                            },
                            {
                                "name": "name2",
                                "identifier": "identifier2",
                                "groupName": "g2",
                                "query": "*",
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "liveMonitoringEnabled": "true",
                                "continuousVerificationEnabled": "false",
                                "sliEnabled": "false",
                                "metricThresholds": [
                                    {
                                        "type": "IgnoreThreshold",
                                        "spec": {
                                            "action": "Ignore",
                                        },
                                        "criteria": {
                                            "type": "Absolute",
                                            "spec": {
                                                "greaterThan": 100,
                                            },
                                        },
                                        "metrictype": "Custom",
                                        "metricName": "identifier2",
                                    },
                                    {
                                        "type": "FailImmediately",
                                        "spec": {
                                            "action": "FailAfterOccurrence",
                                            "spec": {
                                                "count": 2,
                                            },
                                        },
                                        "criteria": {
                                            "type": "Absolute",
                                            "spec": {
                                                "greaterThan": 100,
                                            },
                                        },
                                        "metricType": "Custom",
                                        "metricName": "identifier2",
                                    },
                                ],
                            },
                        ],
                    }),
                }],
            })
        #Sample template for Grafana Loki Log Health Source
        example4 = harness.platform.MonitoredService("example4",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "Test",
                    "identifier": "Test",
                    "type": "GrafanaLokiLogs",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [
                            {
                                "name": "Demo",
                                "identifier": "Demo",
                                "query": "{job=~\\".+\\"}",
                                "groupName": "Log_Group",
                                "queryParams": {
                                    "serviceInstanceField": "job",
                                },
                            },
                            {
                                "name": "log2",
                                "identifier": "identifier2",
                                "groupName": "g2",
                                "query": "error",
                                "queryParams": {
                                    "serviceInstanceField": "_sourcehost",
                                },
                                "liveMonitoringEnabled": "false",
                                "continuousVerificationEnabled": "false",
                                "sliEnabled": "false",
                            },
                        ],
                    }),
                }],
            })
        #Sample template for Azure Metrics Health Source
        example5 = harness.platform.MonitoredService("example5",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "azure metrics verify step",
                    "identifier": "azure_metrics_verify_step",
                    "type": "AzureMetrics",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [
                            {
                                "name": "metric",
                                "identifier": "metric",
                                "query": "default",
                                "groupName": "g1",
                                "queryParams": {
                                    "serviceInstanceField": "host",
                                    "index": "/subscriptions/12d2db62-5aa9-471d-84bb-faa489b3e319/resourceGroups/srm-test/providers/Microsoft.ContainerService/managedClusters/srm-test",
                                    "healthSourceMetricName": "cpuUsagePercentage",
                                    "healthSourceMetricNamespace": "insights.container/nodes",
                                    "aggregationType": "average",
                                },
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "liveMonitoringEnabled": "true",
                                "continuousVerificationEnabled": "true",
                                "sliEnabled": "false",
                                "metricThresholds": [
                                    {
                                        "type": "IgnoreThreshold",
                                        "spec": {
                                            "action": "Ignore",
                                        },
                                        "criteria": {
                                            "type": "Absolute",
                                            "spec": {
                                                "greaterThan": 100,
                                            },
                                        },
                                        "metrictype": "Custom",
                                        "metricName": "metric",
                                    },
                                    {
                                        "type": "FailImmediately",
                                        "spec": {
                                            "action": "FailAfterOccurrence",
                                            "spec": {
                                                "count": 2,
                                            },
                                        },
                                        "criteria": {
                                            "type": "Absolute",
                                            "spec": {
                                                "greaterThan": 100,
                                            },
                                        },
                                        "metricType": "Custom",
                                        "metricName": "metric",
                                    },
                                ],
                            },
                            {
                                "name": "name2",
                                "identifier": "identifier2",
                                "groupName": "g2",
                                "queryParams": {
                                    "serviceInstanceField": "host",
                                    "index": "/subscriptions/12d2db62-5aa9-471d-84bb-faa489b3e319/resourceGroups/srm-test/providers/Microsoft.ContainerService/managedClusters/srm-test",
                                    "healthSourceMetricName": "cpuUsagePercentage",
                                    "healthSourceMetricNamespace": "insights.container/nodes",
                                    "aggregationType": "average",
                                },
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "liveMonitoringEnabled": "false",
                                "continuousVerificationEnabled": "false",
                                "sliEnabled": "false",
                            },
                        ],
                    }),
                }],
            })
        #Sample template for Azure Log Health Source
        example6 = harness.platform.MonitoredService("example6",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "Demo azure",
                    "identifier": "Demo_azure",
                    "type": "AzureLogs",
                    "version": "v2",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "queryDefinitions": [{
                            "name": "name2",
                            "identifier": "identifier2",
                            "groupName": "g2",
                            "query": "*",
                            "queryParams": {
                                "serviceInstanceField": "Name",
                                "timeStampIdentifier": "StartedTime",
                                "messageIdentifier": "Image",
                                "index": "/subscriptions/12d2db62-5aa9-471d-84bb-faa489b3e319/resourceGroups/srm-test/providers/Microsoft.ContainerService/managedClusters/srm-test",
                            },
                            "liveMonitoringEnabled": "false",
                            "continuousVerificationEnabled": "false",
                        }],
                    }),
                }],
            })
        #Sample template for Prometheus Metrics Health Source
        example7 = harness.platform.MonitoredService("example7",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "prometheus metrics verify step",
                    "identifier": "prometheus_metrics",
                    "type": "Prometheus",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "metricDefinitions": [{
                            "identifier": "Prometheus_Metric",
                            "metricName": "Prometheus Metric",
                            "riskProfile": {
                                "riskCategory": "Performance_Other",
                                "thresholdTypes": ["ACT_WHEN_HIGHER"],
                            },
                            "analysis": {
                                "liveMonitoring": {
                                    "enabled": True,
                                },
                                "deploymentVerification": {
                                    "enabled": True,
                                    "serviceInstanceFieldName": "pod_name",
                                },
                            },
                            "query": "count(up{group=\\"cv\\",group=\\"cv\\"})",
                            "groupName": "met",
                            "isManualQuery": True,
                        }],
                        "metricPacks": [{
                            "identifier": "Custom",
                            "metricThresholds": [
                                {
                                    "type": "IgnoreThreshold",
                                    "spec": {
                                        "action": "Ignore",
                                    },
                                    "criteria": {
                                        "type": "Absolute",
                                        "spec": {
                                            "greaterThan": 100,
                                        },
                                    },
                                    "metrictype": "Custom",
                                    "metricName": "Prometheus Metric",
                                },
                                {
                                    "type": "FailImmediately",
                                    "spec": {
                                        "action": "FailAfterOccurrence",
                                        "spec": {
                                            "count": 2,
                                        },
                                    },
                                    "criteria": {
                                        "type": "Absolute",
                                        "spec": {
                                            "greaterThan": 100,
                                        },
                                    },
                                    "metricType": "Custom",
                                    "metricName": "Prometheus Metric",
                                },
                            ],
                        }],
                    }),
                }],
            })
        #Sample template for Datadog Metrics Health Source
        example8 = harness.platform.MonitoredService("example8",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "ddm",
                    "identifier": "ddm",
                    "type": "DatadogMetrics",
                    "spec": json.dumps({
                        "connectorRef": "connectorRef",
                        "feature": "Datadog Cloud Metrics",
                        "metricDefinitions": [
                            {
                                "metricName": "metric",
                                "metricPath": "M1",
                                "identifier": "metric",
                                "query": \"\"\"avg:kubernetes.cpu.limits{*}.rollup(avg, 60);
        avg:kubernetes.cpu.limits{*}.rollup(avg, 30);
        (a+b)/10\"\"\",
                                "isManualQuery": True,
                                "isCustomCreatedMetric": True,
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "analysis": {
                                    "liveMonitoring": {
                                        "enabled": True,
                                    },
                                    "deploymentVerification": {
                                        "enabled": True,
                                        "serviceInstanceFieldName": "pod",
                                    },
                                },
                            },
                            {
                                "metricName": "dashboard_metric_cpu",
                                "identifier": "metric_cpu",
                                "query": \"\"\"avg:kubernetes.cpu.limits{*}.rollup(avg, 60);
        avg:kubernetes.cpu.limits{*}.rollup(avg, 30);
        (a+b)/10\"\"\",
                                "isManualQuery": False,
                                "dashboardName": "dashboard",
                                "metricPath": "M1",
                                "groupingQuery": "avg:kubernetes.cpu.limits{*} by {host}.rollup(avg, 60)",
                                "metric": "kubernetes.cpu.limits",
                                "aggregation": "avg",
                                "isCustomCreatedMetric": True,
                                "riskProfile": {
                                    "riskCategory": "Performance_Other",
                                    "thresholdTypes": ["ACT_WHEN_HIGHER"],
                                },
                                "analysis": {
                                    "liveMonitoring": {
                                        "enabled": True,
                                    },
                                    "deploymentVerification": {
                                        "enabled": True,
                                        "serviceInstanceFieldName": "pod",
                                    },
                                },
                            },
                        ],
                        "metricPacks": [{
                            "identifier": "Custom",
                            "metricThresholds": [
                                {
                                    "type": "IgnoreThreshold",
                                    "spec": {
                                        "action": "Ignore",
                                    },
                                    "criteria": {
                                        "type": "Absolute",
                                        "spec": {
                                            "greaterThan": 100,
                                        },
                                    },
                                    "metrictype": "Custom",
                                    "metricName": "metric",
                                },
                                {
                                    "type": "FailImmediately",
                                    "spec": {
                                        "action": "FailAfterOccurrence",
                                        "spec": {
                                            "count": 2,
                                        },
                                    },
                                    "criteria": {
                                        "type": "Absolute",
                                        "spec": {
                                            "greaterThan": 100,
                                        },
                                    },
                                    "metricType": "Custom",
                                    "metricName": "metric",
                                },
                            ],
                        }],
                    }),
                }],
            })
        #Sample template for New Relic Metrics Health Source
        example9 = harness.platform.MonitoredService("example9",
            org_id="org_id",
            project_id="project_id",
            identifier="identifier",
            request={
                "name": "name",
                "type": "Application",
                "description": "description",
                "service_ref": "service_ref",
                "environment_ref": "environment_ref",
                "tags": [
                    "foo:bar",
                    "bar:foo",
                ],
                "health_sources": [{
                    "name": "name",
                    "identifier": "identifier",
                    "type": "NewRelic",
                    "spec": json.dumps({
                        "connectorRef": "account.Newrelicautomation_do_not_delete",
                        "feature": "apm",
                        "applicationId": "107019083",
                        "applicationName": "My Application",
                        "metricData": {
                            "Performance": True,
                        },
                        "metricPacks": [{
                            "identifier": "Performance",
                        }],
                        "newRelicMetricDefinitions": [{
                            "identifier": "New_Relic_Metric",
                            "metricName": "New Relic Metric",
                            "riskProfile": {
                                "riskCategory": "Performance_Other",
                                "thresholdTypes": ["ACT_WHEN_HIGHER"],
                            },
                            "analysis": {
                                "deploymentVerification": {
                                    "enabled": True,
                                },
                            },
                            "groupName": "group1",
                            "nrql": "SELECT count(apm.service.instance.count) FROM Metric WHERE appName LIKE 'My Application' TIMESERIES",
                            "responseMapping": {
                                "metricValueJsonPath": "$.['timeSeries'].[*].['results'].[*].['count']",
                                "timestampJsonPath": "$.['timeSeries'].[*].['beginTimeSeconds']",
                            },
                        }],
                        "metricPacks": [{
                            "identifier": "Custom",
                            "metricThresholds": [
                                {
                                    "type": "IgnoreThreshold",
                                    "spec": {
                                        "action": "Ignore",
                                    },
                                    "criteria": {
                                        "type": "Absolute",
                                        "spec": {
                                            "greaterThan": 100,
                                        },
                                    },
                                    "metricType": "Custom",
                                    "metricName": "New Relic Metric",
                                },
                                {
                                    "type": "FailImmediately",
                                    "spec": {
                                        "action": "FailAfterOccurrence",
                                        "spec": {
                                            "count": 2,
                                        },
                                    },
                                    "criteria": {
                                        "type": "Absolute",
                                        "spec": {
                                            "greaterThan": 100,
                                        },
                                    },
                                    "metricType": "Custom",
                                    "metricName": "New Relic Metric",
                                },
                            ],
                        }],
                    }),
                }],
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level monitored_service

        ```sh
        $ pulumi import harness:platform/monitoredService:MonitoredService example <monitored_service_id>
        ```

        Import organization level monitored_service

        ```sh
        $ pulumi import harness:platform/monitoredService:MonitoredService example <org_id>/<monitored_service_id>
        ```

        Import project level monitored_service

        ```sh
        $ pulumi import harness:platform/monitoredService:MonitoredService example <org_id>/<project_id>/<monitored_service_id>
        ```

        :param str resource_name: The name of the resource.
        :param MonitoredServiceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MonitoredServiceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 request: Optional[pulumi.Input[Union['MonitoredServiceRequestArgs', 'MonitoredServiceRequestArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MonitoredServiceArgs.__new__(MonitoredServiceArgs)

            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["request"] = request
        super(MonitoredService, __self__).__init__(
            'harness:platform/monitoredService:MonitoredService',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            request: Optional[pulumi.Input[Union['MonitoredServiceRequestArgs', 'MonitoredServiceRequestArgsDict']]] = None) -> 'MonitoredService':
        """
        Get an existing MonitoredService resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the monitored service.
        :param pulumi.Input[_builtins.str] org_id: Identifier of the organization in which the monitored service is configured.
        :param pulumi.Input[_builtins.str] project_id: Identifier of the project in which the monitored service is configured.
        :param pulumi.Input[Union['MonitoredServiceRequestArgs', 'MonitoredServiceRequestArgsDict']] request: Request for creating or updating a monitored service.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MonitoredServiceState.__new__(_MonitoredServiceState)

        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["request"] = request
        return MonitoredService(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the monitored service.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the organization in which the monitored service is configured.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the project in which the monitored service is configured.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def request(self) -> pulumi.Output[Optional['outputs.MonitoredServiceRequest']]:
        """
        Request for creating or updating a monitored service.
        """
        return pulumi.get(self, "request")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InputSetArgs', 'InputSet']

@pulumi.input_type
class InputSetArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 pipeline_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_details: Optional[pulumi.Input['InputSetGitDetailsArgs']] = None,
                 git_import_info: Optional[pulumi.Input['InputSetGitImportInfoArgs']] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 input_set_import_request: Optional[pulumi.Input['InputSetInputSetImportRequestArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a InputSet resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] pipeline_id: Identifier of the pipeline
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input['InputSetGitDetailsArgs'] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input['InputSetGitImportInfoArgs'] git_import_info: Contains Git Information for importing entities from Git
        :param pulumi.Input[_builtins.bool] import_from_git: Flag to set if importing from Git
        :param pulumi.Input['InputSetInputSetImportRequestArgs'] input_set_import_request: Contains parameters for importing a input set
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] yaml: Input Set YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "pipeline_id", pipeline_id)
        pulumi.set(__self__, "project_id", project_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if git_details is not None:
            pulumi.set(__self__, "git_details", git_details)
        if git_import_info is not None:
            pulumi.set(__self__, "git_import_info", git_import_info)
        if import_from_git is not None:
            pulumi.set(__self__, "import_from_git", import_from_git)
        if input_set_import_request is not None:
            pulumi.set(__self__, "input_set_import_request", input_set_import_request)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if yaml is not None:
            pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the pipeline
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pipeline_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Optional[pulumi.Input['InputSetGitDetailsArgs']]:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @git_details.setter
    def git_details(self, value: Optional[pulumi.Input['InputSetGitDetailsArgs']]):
        pulumi.set(self, "git_details", value)

    @_builtins.property
    @pulumi.getter(name="gitImportInfo")
    def git_import_info(self) -> Optional[pulumi.Input['InputSetGitImportInfoArgs']]:
        """
        Contains Git Information for importing entities from Git
        """
        return pulumi.get(self, "git_import_info")

    @git_import_info.setter
    def git_import_info(self, value: Optional[pulumi.Input['InputSetGitImportInfoArgs']]):
        pulumi.set(self, "git_import_info", value)

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to set if importing from Git
        """
        return pulumi.get(self, "import_from_git")

    @import_from_git.setter
    def import_from_git(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "import_from_git", value)

    @_builtins.property
    @pulumi.getter(name="inputSetImportRequest")
    def input_set_import_request(self) -> Optional[pulumi.Input['InputSetInputSetImportRequestArgs']]:
        """
        Contains parameters for importing a input set
        """
        return pulumi.get(self, "input_set_import_request")

    @input_set_import_request.setter
    def input_set_import_request(self, value: Optional[pulumi.Input['InputSetInputSetImportRequestArgs']]):
        pulumi.set(self, "input_set_import_request", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Input Set YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "yaml", value)


@pulumi.input_type
class _InputSetState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_details: Optional[pulumi.Input['InputSetGitDetailsArgs']] = None,
                 git_import_info: Optional[pulumi.Input['InputSetGitImportInfoArgs']] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 input_set_import_request: Optional[pulumi.Input['InputSetInputSetImportRequestArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering InputSet resources.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input['InputSetGitDetailsArgs'] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input['InputSetGitImportInfoArgs'] git_import_info: Contains Git Information for importing entities from Git
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] import_from_git: Flag to set if importing from Git
        :param pulumi.Input['InputSetInputSetImportRequestArgs'] input_set_import_request: Contains parameters for importing a input set
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] pipeline_id: Identifier of the pipeline
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] yaml: Input Set YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if git_details is not None:
            pulumi.set(__self__, "git_details", git_details)
        if git_import_info is not None:
            pulumi.set(__self__, "git_import_info", git_import_info)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if import_from_git is not None:
            pulumi.set(__self__, "import_from_git", import_from_git)
        if input_set_import_request is not None:
            pulumi.set(__self__, "input_set_import_request", input_set_import_request)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if pipeline_id is not None:
            pulumi.set(__self__, "pipeline_id", pipeline_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if yaml is not None:
            pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Optional[pulumi.Input['InputSetGitDetailsArgs']]:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @git_details.setter
    def git_details(self, value: Optional[pulumi.Input['InputSetGitDetailsArgs']]):
        pulumi.set(self, "git_details", value)

    @_builtins.property
    @pulumi.getter(name="gitImportInfo")
    def git_import_info(self) -> Optional[pulumi.Input['InputSetGitImportInfoArgs']]:
        """
        Contains Git Information for importing entities from Git
        """
        return pulumi.get(self, "git_import_info")

    @git_import_info.setter
    def git_import_info(self, value: Optional[pulumi.Input['InputSetGitImportInfoArgs']]):
        pulumi.set(self, "git_import_info", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to set if importing from Git
        """
        return pulumi.get(self, "import_from_git")

    @import_from_git.setter
    def import_from_git(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "import_from_git", value)

    @_builtins.property
    @pulumi.getter(name="inputSetImportRequest")
    def input_set_import_request(self) -> Optional[pulumi.Input['InputSetInputSetImportRequestArgs']]:
        """
        Contains parameters for importing a input set
        """
        return pulumi.get(self, "input_set_import_request")

    @input_set_import_request.setter
    def input_set_import_request(self, value: Optional[pulumi.Input['InputSetInputSetImportRequestArgs']]):
        pulumi.set(self, "input_set_import_request", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the pipeline
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pipeline_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Input Set YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "yaml", value)


@pulumi.type_token("harness:platform/inputSet:InputSet")
class InputSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_details: Optional[pulumi.Input[Union['InputSetGitDetailsArgs', 'InputSetGitDetailsArgsDict']]] = None,
                 git_import_info: Optional[pulumi.Input[Union['InputSetGitImportInfoArgs', 'InputSetGitImportInfoArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 input_set_import_request: Optional[pulumi.Input[Union['InputSetInputSetImportRequestArgs', 'InputSetInputSetImportRequestArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Harness InputSet.

        ## Import

        The `pulumi import` command can be used, for example:

        Import input set

        ```sh
        $ pulumi import harness:platform/inputSet:InputSet example <org_id>/<project_id>/<pipeline_id>/<input_set_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Union['InputSetGitDetailsArgs', 'InputSetGitDetailsArgsDict']] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input[Union['InputSetGitImportInfoArgs', 'InputSetGitImportInfoArgsDict']] git_import_info: Contains Git Information for importing entities from Git
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] import_from_git: Flag to set if importing from Git
        :param pulumi.Input[Union['InputSetInputSetImportRequestArgs', 'InputSetInputSetImportRequestArgsDict']] input_set_import_request: Contains parameters for importing a input set
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] pipeline_id: Identifier of the pipeline
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] yaml: Input Set YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InputSetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness InputSet.

        ## Import

        The `pulumi import` command can be used, for example:

        Import input set

        ```sh
        $ pulumi import harness:platform/inputSet:InputSet example <org_id>/<project_id>/<pipeline_id>/<input_set_id>
        ```

        :param str resource_name: The name of the resource.
        :param InputSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InputSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_details: Optional[pulumi.Input[Union['InputSetGitDetailsArgs', 'InputSetGitDetailsArgsDict']]] = None,
                 git_import_info: Optional[pulumi.Input[Union['InputSetGitImportInfoArgs', 'InputSetGitImportInfoArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 input_set_import_request: Optional[pulumi.Input[Union['InputSetInputSetImportRequestArgs', 'InputSetInputSetImportRequestArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InputSetArgs.__new__(InputSetArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["git_details"] = git_details
            __props__.__dict__["git_import_info"] = git_import_info
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["import_from_git"] = import_from_git
            __props__.__dict__["input_set_import_request"] = input_set_import_request
            __props__.__dict__["name"] = name
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if pipeline_id is None and not opts.urn:
                raise TypeError("Missing required property 'pipeline_id'")
            __props__.__dict__["pipeline_id"] = pipeline_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["yaml"] = yaml
        super(InputSet, __self__).__init__(
            'harness:platform/inputSet:InputSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            git_details: Optional[pulumi.Input[Union['InputSetGitDetailsArgs', 'InputSetGitDetailsArgsDict']]] = None,
            git_import_info: Optional[pulumi.Input[Union['InputSetGitImportInfoArgs', 'InputSetGitImportInfoArgsDict']]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
            input_set_import_request: Optional[pulumi.Input[Union['InputSetInputSetImportRequestArgs', 'InputSetInputSetImportRequestArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            yaml: Optional[pulumi.Input[_builtins.str]] = None) -> 'InputSet':
        """
        Get an existing InputSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Union['InputSetGitDetailsArgs', 'InputSetGitDetailsArgsDict']] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input[Union['InputSetGitImportInfoArgs', 'InputSetGitImportInfoArgsDict']] git_import_info: Contains Git Information for importing entities from Git
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] import_from_git: Flag to set if importing from Git
        :param pulumi.Input[Union['InputSetInputSetImportRequestArgs', 'InputSetInputSetImportRequestArgsDict']] input_set_import_request: Contains parameters for importing a input set
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] pipeline_id: Identifier of the pipeline
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] yaml: Input Set YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InputSetState.__new__(_InputSetState)

        __props__.__dict__["description"] = description
        __props__.__dict__["git_details"] = git_details
        __props__.__dict__["git_import_info"] = git_import_info
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["import_from_git"] = import_from_git
        __props__.__dict__["input_set_import_request"] = input_set_import_request
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["pipeline_id"] = pipeline_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["yaml"] = yaml
        return InputSet(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> pulumi.Output['outputs.InputSetGitDetails']:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @_builtins.property
    @pulumi.getter(name="gitImportInfo")
    def git_import_info(self) -> pulumi.Output[Optional['outputs.InputSetGitImportInfo']]:
        """
        Contains Git Information for importing entities from Git
        """
        return pulumi.get(self, "git_import_info")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Flag to set if importing from Git
        """
        return pulumi.get(self, "import_from_git")

    @_builtins.property
    @pulumi.getter(name="inputSetImportRequest")
    def input_set_import_request(self) -> pulumi.Output[Optional['outputs.InputSetInputSetImportRequest']]:
        """
        Contains parameters for importing a input set
        """
        return pulumi.get(self, "input_set_import_request")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the pipeline
        """
        return pulumi.get(self, "pipeline_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> pulumi.Output[_builtins.str]:
        """
        Input Set YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")

